pub(crate) fn build_version_message(
user_agent: String,
best_block: u32,
peer_address: &LocalAddress,
) -> NetworkMessageExpand description
Build the version message used to perform the peer connection handshake, as described in the Bitcoin Wiki.